# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.key_value_api import KeyValueApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestKeyValueApi(unittest.TestCase):
    """KeyValueApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.key_value_api.KeyValueApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_store(self):
        """Test case for create_store

        Create a new key-value store.  # noqa: E501
        """
        pass

    def test_delete_key(self):
        """Test case for delete_key

        Remove an entry from the key-value store.  # noqa: E501
        """
        pass

    def test_delete_store(self):
        """Test case for delete_store

        Deletes an existing key-value store.  # noqa: E501
        """
        pass

    def test_get_key(self):
        """Test case for get_key

        Get a Key-Value entry  # noqa: E501
        """
        pass

    def test_get_store(self):
        """Test case for get_store

        Get information about a Key-Value store  # noqa: E501
        """
        pass

    def test_list_keys(self):
        """Test case for list_keys

        Get the list of keys currently in a store.  # noqa: E501
        """
        pass

    def test_list_stores(self):
        """Test case for list_stores

        Get information about all Key-Value stores  # noqa: E501
        """
        pass

    def test_put_key(self):
        """Test case for put_key

        Place an entry into the key-value store.  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
