# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.object_api import ObjectApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestObjectApi(unittest.TestCase):
    """ObjectApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.object_api.ObjectApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_bucket(self):
        """Test case for create_bucket

        Create a Bucket  # noqa: E501
        """
        pass

    def test_create_object(self):
        """Test case for create_object

        Create an object in a bucket  # noqa: E501
        """
        pass

    def test_delete_bucket(self):
        """Test case for delete_bucket

        Delete a bucket  # noqa: E501
        """
        pass

    def test_delete_object(self):
        """Test case for delete_object

        Delete an object in a bucket  # noqa: E501
        """
        pass

    def test_get_bucket(self):
        """Test case for get_bucket

        Get a bucket summary  # noqa: E501
        """
        pass

    def test_get_object(self):
        """Test case for get_object

        Get an object in a bucket or list under a prefix  # noqa: E501
        """
        pass

    def test_list_buckets(self):
        """Test case for list_buckets

        Get list of all buckets  # noqa: E501
        """
        pass

    def test_list_objects(self):
        """Test case for list_objects

        Get an object in a bucket or list under a prefix  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
