# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.endpoint_api import EndpointApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestEndpointApi(unittest.TestCase):
    """EndpointApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.endpoint_api.EndpointApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_archive_from_endpoint(self):
        """Test case for get_archive_from_endpoint

        GET archive from a endpoint  # noqa: E501
        """
        pass

    def test_get_from_endpoint(self):
        """Test case for get_from_endpoint

        GET data from a endpoint  # noqa: E501
        """
        pass

    def test_submit_to_endpoint(self):
        """Test case for submit_to_endpoint

        Create a endpoint request (i.e. ingress)  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
