# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.event_api import EventApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestEventApi(unittest.TestCase):
    """EventApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.event_api.EventApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_stream_events(self):
        """Test case for stream_events

        Stream events with SSE  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
