# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import seaplane.gen.carrier
from seaplane.gen.carrier.api.flow_api import FlowApi  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestFlowApi(unittest.TestCase):
    """FlowApi unit test stubs"""

    def setUp(self):
        self.api = seaplane.gen.carrier.api.flow_api.FlowApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_flow(self):
        """Test case for create_flow

        Create a Flow  # noqa: E501
        """
        pass

    def test_delete_flow(self):
        """Test case for delete_flow

        Delete a Flow  # noqa: E501
        """
        pass

    def test_delete_secret(self):
        """Test case for delete_secret

        Delete a single secret k/v.  # noqa: E501
        """
        pass

    def test_get_flow(self):
        """Test case for get_flow

        Get a Flow summary  # noqa: E501
        """
        pass

    def test_get_flow_status(self):
        """Test case for get_flow_status

        Get the status of a flow's composite allocations  # noqa: E501
        """
        pass

    def test_get_secret(self):
        """Test case for get_secret

        Get secret details  # noqa: E501
        """
        pass

    def test_list_flows(self):
        """Test case for list_flows

        Get list of all flows  # noqa: E501
        """
        pass

    def test_list_secrets(self):
        """Test case for list_secrets

        List all secrets  # noqa: E501
        """
        pass

    def test_set_secret(self):
        """Test case for set_secret

        Set the secret value  # noqa: E501
        """
        pass

    def test_set_secrets(self):
        """Test case for set_secrets

        Set all secrets  # noqa: E501
        """
        pass

    def test_stream_flow_events(self):
        """Test case for stream_flow_events

        Stream flow events with SSE  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
